@@ -2,6 +2,8 @@ import logging
 import coloredlogs
 from .handlers import slack
 
+log = logging.getLogger("gytrash")
+
 
 def setup_logging(
     log,
@@ -11,6 +13,7 @@ def setup_logging(
     log_to_slack: bool = False,
     slack_log_channel: str = None,
     slack_log_level: int = 20,
+    slack_bot_token: str = None,
 ) -> None:
     """ Create the Logging handler for the CLI. This setups a log handler that support logging in color.
 
@@ -25,12 +28,14 @@ def setup_logging(
         None
     """
 
-    log_format = (
-        "%(asctime)s %(name)s[%(process)d] %(module)s: %(levelname)s %(message)s"
-    )
+    log_format = "%(asctime)s %(name)s:%(module)s:%(lineno)d[%(process)d]:: %(levelname)s %(message)s"
+
+    log.setLevel(log_level)
+
+    generic_formatter = logging.Formatter(log_format)
 
     coloredlogs.install(level=log_level, logger=log, fmt=log_format)
-    log.debug(f"runway log level: {log.getEffectiveLevel()}")
+    log.debug(f"Gytrash log level: {log.getEffectiveLevel()}")
 
     if log_from_botocore:
         log.debug("Tapping Botocore logger.")
@@ -39,7 +44,8 @@ def setup_logging(
         )
 
     if log_to_slack:
-        sh = slack.SlackHandler(slack_log_channel)
+        sh = slack.SlackHandler(slack_log_channel, slack_bot_token)
+        sh.setFormatter(generic_formatter)
         sh.setLevel(slack_log_level)
         log.addHandler(sh)
 
